Structs
- CfsOptions
- Options for cFS validation and code generation.
Enums
- Error
- Error type returned by the Synapse library facade.
- Lang
- Target language for Synapse code generation.
- MsgId
Layout - cFE message ID layout policy used for command/telemetry validation.
- Registry
Format - Machine-readable packet registry output format.
Functions
- check_
path - Check a
.syninput path, validating its import graph and cFS codegen support. - check_
path_ with_ options - Check a
.syninput path with cFS validation options. - check_
paths - Check one or more
.syninput paths as a mission-visible set. - check_
paths_ with_ options - Check one or more
.syninput paths with cFS validation options. - check_
str - Check
.synsource text for parser and cFS codegen support. - check_
str_ with_ options - Check
.synsource text for parser and cFS codegen support with options. - generate_
c_ file - Generate a cFS C header from an input file.
- generate_
docs - Generate static HTML documentation from one or more
.syninput paths. - generate_
docs_ with_ options - Generate static HTML documentation with cFS validation options.
- generate_
file - Generate code from an input file and write it into
out_dir. - generate_
file_ with_ options - Generate code from an input file with cFS validation options and write it into
out_dir. - generate_
files - Generate the root file and all transitive imports into
out_dir. - generate_
files_ with_ options - Generate the root file and transitive imports with cFS validation options.
- generate_
path - Generate code from a
.syninput path, validating the import graph rooted at that file. - generate_
path_ with_ options - Generate code from a
.syninput path with cFS validation options. - generate_
registry - Generate a machine-readable packet registry from one or more
.syninput paths. - generate_
registry_ with_ options - Generate a machine-readable packet registry with cFS validation options.
- generate_
rust_ file - Generate Rust
#[repr(C)]bindings from an input file. - generate_
str - Generate code from
.synsource text. - generate_
str_ with_ options - Generate code from
.synsource text with cFS validation options. - write_
docs - Generate static HTML documentation and write it to
out_dir/index.html. - write_
docs_ with_ options - Generate static HTML documentation with options and write it to
out_dir/index.html. - write_
registry - Generate a machine-readable packet registry and write it to
output. - write_
registry_ with_ options - Generate a machine-readable packet registry with options and write it to
output.